# Copyright (C) 2021 Cumulus Networks, inc.
#
# All Rights reserved.
#
# This software is subject to the Cumulus Networks End User License Agreement
# available at the following locations:
#
# Internet: https://cumulusnetworks.com/downloads/eula/latest/view/
#
# Cumulus Linux systems: /usr/share/cumulus/EULA.txt


import json
import logging
from pydash import py_


logger = logging.getLogger(__name__)
ptp_domain = 0
ptp_domain_read = 0

###############################
# Raw
###############################


def ptp4l_cli_raw_get(ctx, cmd, arg=None):
    global ptp_domain_read
    global ptp_domain
    if not ptp_domain_read:
        ptp_conf = ctx.linuxptp_v1.getCuev1Ptp4lConfPtp()
        if 'domain' in ptp_conf:
            ptp_domain = ptp_conf['domain']
        else:
            ptp_domain = 0
        ptp_domain_read = 1
    try:
        if arg is None:
            return str(ctx.sh.sudo("/usr/lib/nvue/ptp4l-cli", cmd, ptp_domain))
        else:
            return str(ctx.sh.sudo("/usr/lib/nvue/ptp4l-cli", cmd, arg,
                       ptp_domain))
    except ctx.sh.ErrorReturnCode_1 as ex:
        return ex.stdout.decode()


###############################
# Native
###############################

def ptp4l_cli_get(ctx, cmd, arg=None):
    try:
        return json.loads(ctx.linuxptp_v1.getRawPtp4lCli(cmd, arg))
    except json.JSONDecodeError:
        logger.info("Failed to parse ouput from ptp4l cli")
        return {}


def current_ds_get(ctx, instance_id):
    return ctx.linuxptp_v1.getPtp4lCli("current")


def parent_ds_get(ctx, instance_id):
    return ctx.linuxptp_v1.getPtp4lCli("parent")


def timeprops_ds_get(ctx, instance_id):
    return ctx.linuxptp_v1.getPtp4lCli("props")


def master_ds_get(ctx, instance_id):
    return ctx.linuxptp_v1.getPtp4lCli("master")


def default_ds_get(ctx, instance_id):
    return ctx.linuxptp_v1.getPtp4lCli("default")


def port_ds_get(ctx, instance_id, interface_id):
    return ctx.linuxptp_v1.getPtp4lCli("port", interface_id)


def stats_ds_get(ctx, instance_id, interface_id):
    return ctx.linuxptp_v1.getPtp4lCli("stats", interface_id)


###############################
# Translated
###############################

def cuev1_current_ptp_current_get(ctx):
    return ctx.linuxptp_v1.getPtp4lCurrentDS(1)


def cuev1_parent_ptp_parent_get(ctx):
    return ctx.linuxptp_v1.getPtp4lParentDS(1)


def cuev1_time_ptp_timeprops_get(ctx):
    return ctx.linuxptp_v1.getPtp4lTimePropsDS(1)


def cuev1_default_ptp_clock_quality_get(ctx):
    default_ds = ctx.linuxptp_v1.getPtp4lDefaultDS(1)
    cq = default_ds["clock-quality"]

    # Patch up a mispelling in the tool
    if 'offset-sclaled-log-variance' in cq:
        cq = dict(cq)
        cq['offset-scaled-log-variance'] = cq['offset-sclaled-log-variance']
        del cq['offset-sclaled-log-variance']

    return cq


def cuev1_port_if_ptp_get(ctx, interface_id):
    port_ds = ctx.linuxptp_v1.getPtp4lPortDS(1, interface_id)
    return {
        'port-state': port_ds['port-state'],
        'peer-mean-path-delay': port_ds['peer-mean-path-delay'],
        'protocol-version': port_ds['protocol-version']
    }


def cuev1_stats_if_ptp_get(ctx, interface_id):
    stats_ds = ctx.linuxptp_v1.getPtp4lStatsDS(1, interface_id)
    # The native layer closely matches the cue_v1 model.  We just
    # need to remove a few fields.
    return py_.omit(stats_ds, "port_id")
